"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWeatherData = exports.weatherCodeToString = exports.timeFormatter = void 0;
const moment_1 = __importDefault(require("moment"));
function timeFormatter(date, format = 'YYYY/MM/DD HH:mm') {
    const stringTime = new Date(date.replace(/^(\d{4})(\d\d)(\d\d)(\d\d)(\d\d)$/, '$4:$5:$6 $2/$3/$1'));
    return (0, moment_1.default)(stringTime).format(format);
}
exports.timeFormatter = timeFormatter;
function weatherCodeToString(code) {
    const codes = {
        0: 'Cerah',
        1: 'Cerah Berawan',
        2: 'Cerah Berawan',
        3: 'Berawan',
        4: 'Berawan Tebal',
        5: 'Udara Kabur',
        10: 'Asap',
        45: 'Kabut',
        60: 'Hujan Ringan',
        61: 'Hujan Sedang',
        63: 'Hujan Lebat',
        80: 'Hujan Lokal',
        95: 'Hujan Petir',
        97: 'Hujan Petir'
    };
    let key = null;
    Object.keys(codes).forEach((keys) => {
        if (code == Number(keys)) {
            key = keys;
        }
    });
    if (key != null) {
        return codes[key];
    }
    else {
        return 'Kode cuaca tidak dapat diterjemahkan.';
    }
}
exports.weatherCodeToString = weatherCodeToString;
function getWeatherData(parsedXML) {
    const weatherArray = [], areaArray = [];
    const { issue, ...rest } = parsedXML.data.forecast;
    let n;
    rest.area[rest.area.length - 1].hasOwnProperty('parameter') ? (n = 0) : (n = 1);
    for (let i = 0; i < rest.area.length - n; i++) {
        for (let j = 0; j < 12; j++) {
            weatherArray.push({
                waktu: timeFormatter(rest.area[i].parameter[6].timerange[j]['@_datetime']),
                cuaca: weatherCodeToString(rest.area[i].parameter[6].timerange[j].value['#text']),
                temperatur: {
                    celsius: rest.area[i].parameter[5].timerange[j].value[0]['#text'],
                    fahrenheit: rest.area[i].parameter[5].timerange[j].value[1]['#text']
                }
            });
        }
        areaArray.push({
            kota: rest.area[i].name[0]['#text'],
            prakiraan_cuaca: weatherArray
        });
    }
    const obj = {
        timestamp: {
            tahun: issue.year,
            bulan: issue.month,
            tanggal: issue.day,
            jam: issue.hour,
            menit: issue.minute,
            detik: issue.second
        },
        daerah: areaArray
    };
    return obj;
}
exports.getWeatherData = getWeatherData;
